@@ -4,9 +4,9 @@
     "This is 'rpostgis' version ", utils::packageVersion("rpostgis"), " (",
     utils::packageDate("rpostgis"), ") \n",
     "------------------ \n",
-    "`rpostgis` is under new maintenance, and development will be moving to a new location soon! For more information, see: https://github.com/mablab/rpostgis/issues/28 \n",
+    "`rpostgis` is under new maintenance, and development have been moved to https://github.com/Cidree/rpostgis/ \n",
     "------------------ \n",
     "Support for `sp` and `raster` objects will be deprecated in {rpostgis} and will be removed ",
     "in a future release of the package. Please use `sf` and `terra` objects with {rpostgis}"
   )
-}
\ No newline at end of file
+}
